pub struct Task { /* private fields */ }Expand description
A task that executes a function to the end.
Each task is associated with per-task data and an optional user space. If having a user space, the task can switch to the user space to execute user code. Multiple tasks can share a single user space.
Implementations
Sourceimpl Task
impl Task
Sourcepub fn current() -> Option<CurrentTask>
pub fn current() -> Option<CurrentTask>
Gets the current task.
It returns None if the function is called in the bootstrap context.
Sourcepub fn need_yield() -> bool
pub fn need_yield() -> bool
Returns whether we need to yield execution to another task.
If the scheduler decides to preempt the current task in favor of
another (for example, if the current task has exhausted its runtime
budget or if the new task has a higher priority), this method will
return true.
Sourcepub fn yield_now()
pub fn yield_now()
Yields execution so that another task may be scheduled.
Note that this method cannot be simply named “yield” as the name is a Rust keyword.
Sourcepub fn run(self: &Arc<Self>)
pub fn run(self: &Arc<Self>)
Kicks the task scheduler to run the task.
BUG: This method highly depends on the current scheduling policy.
Sourcepub fn schedule_info(&self) -> &TaskScheduleInfo
pub fn schedule_info(&self) -> &TaskScheduleInfo
Get the attached scheduling information.